package com.biganto.visual.roompark.presentation.screen.albums

import android.os.Bundle
import android.view.View
import androidx.core.os.bundleOf
import androidx.recyclerview.widget.LinearLayoutManager
import androidx.recyclerview.widget.RecyclerView
import butterknife.BindView
import com.biganto.visual.roompark.R
import com.biganto.visual.roompark.base.IBottomNavigation
import com.biganto.visual.roompark.base.RoomParkApplication
import com.biganto.visual.roompark.base.RoomParkMainActivity
import com.biganto.visual.roompark.conductor.BigantoBaseController
import com.biganto.visual.roompark.presentation.screen.favorites.util.AlbumListAdapter
import com.biganto.visual.roompark.presentation.screen.feeds.utils.AlbumsPreviewAdapter
import com.biganto.visual.roompark.util.view_utils.grid.CeilsDecoration
import javax.inject.Inject


/**
 * Created by Vladislav Bogdashkin on 30.09.2019.
 */

const val SELECTED_ALBUM_INDEX_KEY = "SELECTED_ALBUM_INDEX"

class AlbumsScreenController :
    BigantoBaseController<AlbumsScreenViewState
            , AlbumsScreen
            , AlbumsScreenPresenter>
   , AlbumsScreen {

    constructor(args: Bundle):super(args)

    constructor(id: Int) : super(bundleOf(SELECTED_ALBUM_INDEX_KEY to id))


    @BindView(R.id.headers_recycler_view)
    lateinit var headersRecyclerView: RecyclerView

    @BindView(R.id.albums_recycler_view)
    lateinit var albumsRecyclerView: RecyclerView



    private fun bindRecycler() {
        headersRecyclerView.isNestedScrollingEnabled = true
        headersRecyclerView.layoutManager =
            LinearLayoutManager(activity, RecyclerView.HORIZONTAL, false)
        headersRecyclerView.adapter = AlbumsPreviewAdapter()
        headersRecyclerView.itemAnimator = null

        if (headersRecyclerView.itemDecorationCount == 0)
            headersRecyclerView.addItemDecoration(
                CeilsDecoration(1
                    , resources?.getDimensionPixelSize(R.dimen.ceil_grid_padding))
            )

        albumsRecyclerView.isNestedScrollingEnabled = true
        albumsRecyclerView.layoutManager =
            LinearLayoutManager(activity, RecyclerView.VERTICAL, false)
        albumsRecyclerView.adapter = AlbumListAdapter()
        albumsRecyclerView.itemAnimator = null
    }

    override fun onViewBound(v: View) {
        toolBar.hideAll()
        bottomNavigation.hide()
        bindRecycler()
    }

    override fun injectDependencies() {
        getComponent()
    }

    @Inject
    override lateinit var injectedPresenter: AlbumsScreenPresenter


//    @Inject
//    lateinit var snacky:ISnackBarProvider

    lateinit var rpActivity: RoomParkMainActivity

    fun getComponent() = DaggerAlbumsScreenComponent
        .factory()
        .create(RoomParkApplication.component
            ,activity as RoomParkMainActivity
            ,args.getInt(SELECTED_ALBUM_INDEX_KEY))
        .inject(this)

//    @Inject
//    lateinit var ac: RoomParkMainActivity

    @Inject
    lateinit var bottomNavigation: IBottomNavigation

    override fun render(viewState: AlbumsScreenViewState) {
        when(viewState){
            is AlbumsScreenViewState.Idle -> render(viewState)
            is AlbumsScreenViewState.AlbumsSelected -> render(viewState)
            is AlbumsScreenViewState.AlbumsListLoaded-> render(viewState)
            is AlbumsScreenViewState.SomeError -> render(viewState)
        }
    }

    private fun render(viewState: AlbumsScreenViewState.Idle){

    }

    private fun render(viewState: AlbumsScreenViewState.SomeError) =
        showError(viewState.exception)

    private fun render(viewState: AlbumsScreenViewState.AlbumsListLoaded) {
        (headersRecyclerView.adapter as AlbumsPreviewAdapter).setItems(viewState.list)

        headersRecyclerView.let {
            it.scrollToPosition(
                (it.adapter as AlbumsPreviewAdapter).getItemPosition(viewState.selectedAlbumId)
            )
        }
    }

    private fun render(viewState: AlbumsScreenViewState.AlbumsSelected){
        (albumsRecyclerView.adapter as AlbumListAdapter).setItems(viewState.list)
    }


    override fun getLayoutId(): Int = R.layout.albums_screen

}